      Subroutine param_set ( freq,freq_radar,wavel,
     &                       inc_angle_mwr,inc_angle_rdr,
     &                       znth_slr,znth_obs,azmth,
     &                       background,slant_path,
     &                       microw,radar,visIR,lut )
      Implicit NONE
c
      Include 'MAINparameters.inc'
c
c Input: 
c    (NONE)
c Outputs: 
c  - sensor parameters and running options
c    freq,freq_radar,wavel,inc_angle_mwr,inc_angle_rdr,znth_slr,
c    znth_obs,azmth,background,slant_path,microw,radar,visIR,lut
c
c 1. Microwave radiometer -------------------------------------------
c
c 1.1 Microwave-radiometer simulation is skipped when microw = .false.
c
      microw = .true.
c
c 1.2 Channel frequencies [GHz]
c    # of channels are defined by "mxfreq" in "MAINparameters.inc".
c
      freq(1) = 10.7
      freq(2) = 19.35
      freq(3) = 21.3
      freq(4) = 37.0 
      freq(5) = 85.5
c
c 1.3 viewing angle [deg]
c
      inc_angle_mwr = 52.8
c
c 1.4 "slanth path" option (.true. or .false.)
c    The satellite-viewing path is assumed to intersect neighboring
c    culumns when true. The independent pixel approximation is applied 
c    when false.
c
      slant_path = .false.
c
c 2. Radar ---------------------------------------------------------
c
c 2.1 Radar simulation is skipped when radar = .false.
c
      radar = .true.
c
c 2.2 Channel frequencies [GHz]
c    # of channels are defined by "mxfreq_radar" in "MAINparameters.inc".
c
      freq_radar(1) = 13.6
c
c 2.3 viewing angle [deg]
c
      inc_angle_rdr = 0.
c
c 3. Visible and IR radiometer -------------------------------------
c
c 3.1 Visble/IR radiometer simulation is skipped when visIR = .false.
c     
      visIR = .true.
c
c 3.2 Channel wavelengths [micron]
c    # of channels are defined by "mxwavel" in "MAINparameters.inc".
c
      wavel(1) = 0.62
      wavel(2) = 1.6
      wavel(3) = 3.8 
      wavel(4) = 10.8
      wavel(5) = 12.0
c
c 3.3 solar and viewing zenith angles [deg]
c
      znth_slr = 60.
      znth_obs = 40.
c
c 3.4 azimuth angle between the sun and sensor [deg]
c
      azmth    = 50.
c
c 4. general options
c
c 4.1 surface background ('water' or 'land')
c     Applicable for microwave and visible/IR radiometer simulations.
c     A Lambert surface is introduced when 'land'.
c
      background = 'water'
c
c 4.2 Mie lookup table (LUT) (.true. or .false.)
c     Mie LUT files must be created in advance when true. 
c     Applicable for microwave radiometer and radar simulations.
c     Make sure that the LUT name is properly specified in
c     "microw/open-lut-mwr.f" and "radar/open-lut-rdr.f".
c     Changing channel frequencies does not automatically redefine
c     the LUT name, so "nch(i)" should be changed manually.
c
      lut = .true.
c
      Return
      End

