      SUBROUTINE ADISC(M,L,NDA,NA0,AM0,WMP,TC,T1,ZEE,QE,QIE
     &  ,VPE,VME,ALFA,BETA,NPLK1,DPE,DME,UDN,UUP)
C INTENSITY AT A USER DEFINED DEPTH.
C--- HISTORY
C 87. 3. 9
C 89.11. 2 MODIFIED
C--- INPUT
C M        I          FOURIER ORDER
C L        I          LAYER NUMBER.
C NDA      I          NUMBER OF QUADRATURE POINTS.
C NA0      I          NUMBER OF SOLAR ZENITH ANGLES.
C AM0    R(KNA0)      COS(SOLAR ZENITH ANGLES).
C WMP    R(KNDM)      SQRT(W*M)
C TC       R          OPTICAL THICKNESS OF THE LAYER.
C T1       R          OPITCAL DEPTH OF INTERPOLATION MEASURED FROM TOP.
C ZEE    R(KNDM,KNLN)  EIGENVALUES
C QE    R(KNDM,KNDM,KNLN)
C QIE   R(KNDM,KNDM,KNLN)
C VPE   R(KNDM,KNA0,KNLN)
C VME   R(KNDM,KNA0,KNLN)
C DPE   R(KNDM,KPLK1,KNLN)
C DME   R(KNDM,KPLK1,KNLN)
C ALFA  R(KNDM,KNA0)  INTEGRAL CONSTANT ALFA.
C BETA  R(KNDM,KNA0)  INTEGRAL CONSTATN BETA.
C--- OUTPUT
C UUP   R(KNDM,KNA0)  UPWARD INTENSITY (UNSCALE)
C UDN   R(KNDM,KNA0)  DNWARD INTENSITY (UNSCALE)
C
C
      include 'VISIRparameters.inc'
c
c      PARAMETER (KNLN  =50)
c      PARAMETER (KNA0  =10)
c      PARAMETER (KNDM  =10)
c      PARAMETER (KPLK1 =2)
C--- AREAS FOR THE ROUTINE
      DIMENSION AM0(NA0),ZEE(KNDM,KNLN),WMP(KNDM)
     &,QE(KNDM,KNDM,KNLN),QIE(KNDM,KNDM,KNLN)
     &,VPE(KNDM,KNA0,KNLN),VME(KNDM,KNA0,KNLN)
     &,ALFA(KNDM,KNA0),BETA(KNDM,KNA0)
     &,DPE(KNDM,KPLK1,KNLN),DME(KNDM,KPLK1,KNLN)
     &,UUP(KNDM,KNA0),UDN(KNDM,KNA0)
C--- WORK AREAS
      DIMENSION C(KNDM),SL(KNDM),SL1(KNDM),E0(KNA0)
     & ,AP(KNDM),AM(KNDM),BP(KNDM),BM(KNDM)
C A+-, B+-
      DO 1 I=1,NDA
    1 CALL CSFN(TC,T1,ZEE(I,L),C(I),SL(I),SL1(I))
      DO 2 J=1,NA0
      EX1=-T1/AM0(J)
    2 E0(J)=EXPFN(EX1)
C U+ = S1D,  U- = S1U
      DO 3 I=1,NDA
        DO 4 J=1,NDA
        AP(J)=QE(I,J,L)*C  (J) - QIE(J,I,L)*SL(J)
        AM(J)=QE(I,J,L)*C  (J) + QIE(J,I,L)*SL(J)
        BP(J)=QE(I,J,L)*SL1(J) - QIE(J,I,L)*C (J)
    4   BM(J)=QE(I,J,L)*SL1(J) + QIE(J,I,L)*C (J)
        DP=0
        DM=0
        IF(M.EQ.0 .AND. NPLK1.GT.0) THEN
          TAUN=1
          DO 5 J=1,NPLK1
          DP=DP+DPE(I,J,L)*TAUN
          DM=DM+DME(I,J,L)*TAUN
    5     TAUN=TAUN*T1
        ENDIF
        DO 3 J=1,NA0
        SUM1=0
        SUM2=0
        DO 6 K=1,NDA
        SUM1=SUM1+AP(K)*ALFA(K,J)+BP(K)*BETA(K,J)
    6   SUM2=SUM2+AM(K)*ALFA(K,J)+BM(K)*BETA(K,J)
        UDN(I,J)=(SUM1+VPE(I,J,L)*E0(J)+DP)/WMP(I)
        UUP(I,J)=(SUM2+VME(I,J,L)*E0(J)+DM)/WMP(I)
    3 CONTINUE
      RETURN
      END
