      FUNCTION SEARF1(AMUE,AMUI,PHI,U10,CR,CI)
C BIDIRECTIONAL REFLECTIVITY OF OCEAN SURFACE
C SHADOWING FACTOR FOR SINGLE SCATTERING
C SO THAT ENERGY CONSERVATION IS NOT SATISFIED
C--- HISTORY
C 92. 9. 1 CREATED BY HASUMI
C    12.23 MODIFIED BY NAKAJIMA
C 95. 6. 2 Generated from SEAREF with CR and CI
C 2000.2.3 Debug parameter for FRNLR.
C--- INPUT
C AMUE     R    COSINE OF ZENITH ANGLE OF EMERGENT RAY .GT. 0
C AMUI     R    COSINE OF ZENITH ANGLE OF INCIDENT RAY .GT. 0
C PHI      R    AZIMURTHAL ANGLE  (RADIAN)
C U10      R    WIND VELOCITY IN M/S AT 10M HEIGHT
C CR       R    Relative refractive index of the media
C               About 1.33 for atmosphere to ocean incidence,
C               and 1/1.33 for ocean to atmosphere incidence.
C CI       R    Relative refractive index for imaginary part
C               M = CR + I*CI
C--- OUTPUT
C SEAREF  RF    BIDIRECTIONAL REFLECTION FUNCTION
C
      PARAMETER (PI = 3.141592654,SQRTPI=1.7724539)
C2000.2.3. Add RAD by T.Y.NAKAJIMA
      PARAMETER (RAD=PI/180.0)
      AMUE1=MAX(AMUE,1.0E-7)
      ALPHA=-AMUE1*AMUI+SQRT((1-AMUE1**2)*(1-AMUI**2))*COS(PHI)
      COSW=SQRT((1-ALPHA)/2.0)
      AMUN=(AMUE1+AMUI)/2/COSW
C SHADOWING FACTOR
      SIGMA=SQRT(5.34E-3*U10)
      VIE =SIGMA*SQRT(1-AMUE1**2)/AMUE1
      IF (VIE. GT. 0.15) THEN
        VE =1/VIE
        FE=(EXP(- VE**2)/SQRTPI/VE-ERFC(VE))/2
       ELSE
        FE=0
      ENDIF
      VII =SIGMA*SQRT(1-AMUI**2)/AMUI
      IF (VII. GT. 0.15) THEN
        VI =1/VII
        FI=(EXP(- VI**2)/SQRTPI/VI-ERFC(VI))/2
       ELSE
        FI=0
      ENDIF
      G=1.0/(1+FE+FI)
C
C Debug 2000.2.3 T.Y.Nakajima. By report of Norman G. Loeb (NASA LaRC)
C
      WI=ACOS(COSW)/RAD
C      CALL FRNLR(CR,CI,COSW,COSWT,R1,R2)
      CALL FRNLR(CR,CI,WI,WR,R1,R2)
C
      R=(R1+R2)/2
      P=1/PI/SIGMA**2/AMUN**3*EXP(-(1-AMUN**2)/(SIGMA*AMUN)**2)
      SEARF1=1.0/4/AMUE1/AMUN*G*P*R
      RETURN
      END
