      FUNCTION SGLR (AM1, AM0, NL, TC, W, P, UT)
C SINGLY SCATTERED INTENSITY (MULTI-LAYER) BY EQ. (12) OF NT.
C--- REFERENCE
C NT:  T. NAKAJIMA AND M. TANAKA, 1988, JQSRT, 40, 51-69
C--- HISTORY
C 89. 2.22   CREATED BY T. NAKAJIMA
C              FROM AIDS BY CHANGING THE MEANING OF T, W, P,
C              AND UT.  UT IS A LEVEL INSIDE THE MULTI-LAYER SYSTEM.
C     5. 4   PATCH FOR EXPONENTIAL OVERFLOW.
C     6.20   REFORM STYLE.
C    12.20   WITH CPEX(3)
C 90.12. 1   PUT IF(IALM... OUT OF DO-LOOP (FOR OPTIMIZATION)
C FOLLOWINGS ARE DEFINITIONS OF SYMBOLS IN THE ROUTINE, WITH THE FORMAT:
C NAME    TYPE       CONTENT
C WHERE TYPE = S (SUBROUTINE), F (FUNCTION), I (INTEGER), R (REAL).
C FOR THE TYPE = I AND R, THE SIZE OF ARRAY IS SHOWN BY ( ).
C--- INPUT
C AM1      R         COS(EMERGENT ZENITH ANGLE) WITH THE SIGN OF
C                    TRANSMITTED( .GT.0),  REFLECTED( .LT.0).
C AM0      R         COS(INCIDENT ZENITH ANGLE) .GT. 0.
C NL       I         NO. OF SUBLAYERS.
C TC     R(NL)       OPTICAL THICKNESS OF SUBLAYER.
C W      R(NL)       SINGLE SCATTERING ALBEDO OF SUBLAYER.
C P      R(NL)       PHASE FUNCTION OF SUBLAYER.
C                    INTEGRATION OVER UNIT SPHERE SHOULD BE 1.
C UT       R         USER DEFINED OPTICAL DEPTH FOR THE INTENSITY
C                    WITHIN THE MULTI-LAYERED SYSTEM.
C--- OUTPUT
C SGLR     F         SINGLY SCATTERED INTENSITY.
      SAVE INIT,EPS
      DIMENSION TC(*),W(*),P(*),CCP(3)
      LOGICAL IALM,IST
      DATA INIT/1/
      IF(INIT.GT.0) THEN
        INIT=0
        CALL CPCON(CCP)
        EPS=CCP(1)*30
      ENDIF
C SET EPS: IF ABS(1/AM1 - 1/AM0) .LE. EPS THEN
C                      THE ROUTINE SETS ALMUCANTAR CONDITION-IALM.
      SGLR=0
      X=1/AM1-1/AM0
      IF(ABS(X).LE.EPS) THEN
        IALM=.TRUE.
        ELSE
        IALM=.FALSE.
      ENDIF
      T2=0
      IST=.TRUE.
C X=0 (TRANSMISSION)
      IF(IALM) THEN
        DO 11 L=1,NL
        T1=T2
        T2=T1+TC(L)
        IF(UT.LE.T1) GOTO 13
        IF(UT.LT.T2) T2=UT
        IF(IST) THEN
          IST=.FALSE.
          E2=T1
        ENDIF
        E1=E2
        E2=T2
        SGLR=SGLR+W(L)*P(L)*(E2-E1)
 11     CONTINUE
       ELSE
C X<>0
      DO 21 L=1,NL
        T1=T2
        T2=T1+TC(L)
CC REFLECTION
        IF(AM1.LT.0) THEN
          IF(UT.GE.T2) GOTO 21
          IF(UT.GT.T1) T1=UT
CC TRANSMISSION
         ELSE
          IF(UT.LE.T1) GOTO 13
          IF(UT.LT.T2) T2=UT
        ENDIF
C
        IF(IST) THEN
          IST=.FALSE.
          E2=T1*X
          E2=EXPFN(E2)/X
        ENDIF
        E1=E2
        E2=T2*X
        E2=EXPFN(E2)/X
        SGLR=SGLR+W(L)*P(L)*(E2-E1)
 21   CONTINUE
      ENDIF
 13   E1=-UT/AM1
      SGLR=SGLR*EXPFN(E1)/ABS(AM1)
      RETURN
      END
