      SUBROUTINE SYMTRX(ROWIJ,M,ROOT,EIGV,NI,WK,IER)
C SOLVES EIGENFUNCTION PROBLEM FOR SYMMETRIC MATRIX
C--- HISTORY
C 89.12. 4 MODIFIED WITH CNCPU
C 90. 1. 6 CNCPU IS REPLACED BY PREC.
C--- INPUT
C M       I      ORDER OF ORIGINAL SYMMETRIC MATRIX
C NI      I      INITIAL DIMENSION OF -ROOT-, -EIGV- AND -WK-
C ROWIJ  R(*)    SYMMETRIC STORAGE MODE OF ORDER M*(M+1)/2
C--- OUTPUT
C EIGV   R(NI,M) EIGENVECTORS OF ORIGINAL SYMMETRIC MATRIX
C IER     I      INDEX FOR ROOT(J) FAILED TO CONVERGE (J=IER-128)
C ROOT   R(M)    EIGENVALUES OF ORIGINAL SYMMETRIC MATRIX
C ROWIJ          STORAGE OF HOUSEHOLDER REDUCTION ELEMENTS
C WK             WORK AREA
C$ENDI
      REAL ROWIJ(*),ROOT(*),WK(*),EIGV(NI,*),CCP(3)
C+++ ADD EPSCP
C     DATA  RDELP/ 1.1921E-07 /
      CALL CPCON(CCP)
      RDELP=CCP(1)*10
C+++
      IER = 0
      MP1 = M + 1
      MM = (M*MP1)/2 - 1
      MBEG = MM + 1- M
C
C+---------------------------------------------------------------------+
C|          LOOP-100 REDUCE -ROWIJ- (SYMMETRIC STORAGE MODE) TO A      |
C|          SYMMETRIC TRIDIAGONAL FORM BY HOUSEHOLDER METHOD           |
C|                      CF. WILKINSON, J.H., 1968,                     |
C|              THE ALGEBRAIC EIGENVALUE PROBLEM, PP 290-293.          |
C|          LOOP-30&40 AND 50 FORM ELEMENT OF A*U AND ELEMENT P        |
C+---------------------------------------------------------------------+
      DO 100 II=1,M
      I = MP1 - II
      L = I - 1
      H = 0.0
      SCALE = 0.0
      IF (L.LT.1) THEN
C|          SCALE ROW (ALGOL TOL THEN NOT NEEDED)
      WK(I) = 0.0
      GO TO 90
      END IF
      MK = MM
      DO 10 K=1,L
      SCALE = SCALE + ABS(ROWIJ(MK))
      MK = MK - 1
   10 CONTINUE
      IF (SCALE.LE.0.0) THEN
      WK(I) = 0.0
      GO TO 90
      END IF
C
      MK = MM
      DO 20 K = 1,L
      ROWIJ(MK) = ROWIJ(MK)/SCALE
      H = H + ROWIJ(MK)*ROWIJ(MK)
      MK = MK - 1
   20 CONTINUE
      WK(I) = SCALE*SCALE*H
      F = ROWIJ(MM)
      G = - SIGN(SQRT(H),F)
      WK(I) = SCALE*G
      H = H - F*G
      ROWIJ(MM) = F - G
      IF (L.GT.1) THEN
      F = 0.0
      JK1 = 1
      DO 50 J=1,L
      G = 0.0
      IK = MBEG + 1
      JK = JK1
      DO 30 K=1,J
      G = G + ROWIJ(JK)*ROWIJ(IK)
      JK = JK + 1
      IK = IK + 1
   30 CONTINUE
      JP1 = J + 1
      IF (L.GE.JP1) THEN
      JK = JK + J - 1
      DO 40 K=JP1,L
      G = G + ROWIJ(JK)*ROWIJ(IK)
      JK = JK + K
      IK = IK + 1
   40 CONTINUE
      END IF
      WK(J) = G/H
      F = F + WK(J)*ROWIJ(MBEG+J)
      JK1 = JK1 + J
   50 CONTINUE
      HH = F/(H+H)
C
      JK = 1
      DO 70 J=1,L
      F = ROWIJ(MBEG+J)
      G = WK(J) - HH*F
      WK(J) = G
      DO 60 K=1,J
      ROWIJ(JK) = ROWIJ(JK) - F*WK(K) - G*ROWIJ(MBEG+K)
      JK = JK + 1
   60 CONTINUE
   70 CONTINUE
      END IF
C
      DO 80 K=1,L
      ROWIJ(MBEG+K) = SCALE*ROWIJ(MBEG+K)
   80 CONTINUE
   90 ROOT(I) = ROWIJ(MBEG+I)
      ROWIJ(MBEG+I) = H*SCALE*SCALE
      MBEG = MBEG - I + 1
      MM = MM - I
  100 CONTINUE
C
C+---------------------------------------------------------------------+
C|          LOOP-210 COMPUTE EIGENVALUES AND EIGENVECTORS              |
C|          SETUP WORK AREA LOCATION EIGV TO THE IDENTITY MATRIX       |
C|          LOOP-140 FOR FINDING SMALL SUB-DIAGONAL ELEMENT            |
C|          LOOP-160 FOR CONVERGENCE OF EIGENVALUE J (MAX. 30 TIMES)   |
C|          LOOP-190 FOR QL TRANSFORMATION AND LOOP-180 FORM VECTORS   |
C+---------------------------------------------------------------------+
      DO 110 I=1,M-1
  110 WK(I) = WK(I+1)
      WK(M) = 0.0
      B = 0.0
      F = 0.0
      DO 130 I=1,M
      DO 120 J=1,M
  120 EIGV(I,J) = 0.0
      EIGV(I,I) = 1.0
  130 CONTINUE
C
      DO 210 L=1,M
      J = 0
      H = RDELP*(ABS(ROOT(L))+ABS(WK(L)))
      IF (B.LT.H) B = H
      DO 140 N=L,M
      K = N
      IF (ABS(WK(K)).LE.B) GO TO 150
  140 CONTINUE
  150 N = K
      IF (N.EQ.L) GO TO 200
C
  160 CONTINUE
      IF (J.EQ.30) THEN
      IER = 128 + L
      RETURN
      END IF
C
      J = J + 1
      L1 = L + 1
      G = ROOT(L)
      P = (ROOT(L1)-G)/(WK(L)+WK(L))
      R = ABS(P)
      IF (RDELP*ABS(P).LT.1.0) R = SQRT(P*P+1.0)
      ROOT(L) = WK(L)/(P+SIGN(R,P))
      H = G - ROOT(L)
      DO 170 I=L1,M
      ROOT(I) = ROOT(I) - H
  170 CONTINUE
      F = F + H
C
      P = ROOT(N)
      C = 1.0
      S = 0.0
      NN1 = N - 1
      NN1PL = NN1 + L
      IF (L.LE.NN1) THEN
      DO 190 II=L,NN1
      I = NN1PL - II
      G = C*WK(I)
      H = C*P
      IF (ABS(P).LT.ABS(WK(I))) THEN
      C = P/WK(I)
      R = SQRT(C*C+1.0)
      WK(I+1) = S*WK(I)*R
      S = 1.0/R
      C = C*S
      ELSE
      C = WK(I)/P
      R = SQRT(C*C+1.0)
      WK(I+1) = S*P*R
      S = C/R
      C = 1.0/R
      END IF
      P = C*ROOT(I) - S*G
      ROOT(I+1) = H + S*(C*G+S*ROOT(I))
      IF (NI.GE.M) THEN
      DO 180 K=1,M
      H = EIGV(K,I+1)
      EIGV(K,I+1) = S*EIGV(K,I) + C*H
      EIGV(K,I) = C*EIGV(K,I) - S*H
  180 CONTINUE
      END IF
  190 CONTINUE
      END IF
      WK(L) = S*P
      ROOT(L) = C*P
      IF (ABS(WK(L)).GT.B) GO TO 160
  200 ROOT(L) = ROOT(L) + F
  210 CONTINUE
C
C+---------------------------------------------------------------------+
C|          BACK TRANSFORM EIGENVECTORS OF THE ORIGINAL MATRIX FROM    |
C|          EIGENVECTORS 1 TO M OF THE SYMMETRIC TRIDIAGONAL MATRIX    |
C+---------------------------------------------------------------------+
      DO 250 I=2,M
      L = I - 1
      IA = (I*L)/2
      IF (ABS(ROWIJ(IA+I)).GT.0.0) THEN
      DO 240 J=1,M
      SUM = 0.0
      DO 220 K=1,L
      SUM = SUM + ROWIJ(IA+K)*EIGV(K,J)
  220 CONTINUE
      SUM = SUM/ROWIJ(IA+I)
      DO 230 K=1,L
      EIGV(K,J) = EIGV(K,J) - SUM*ROWIJ(IA+K)
  230 CONTINUE
  240 CONTINUE
      END IF
  250 CONTINUE
C
      RETURN
      END
