      SUBROUTINE TRN1(NSB,NDD,NA0,IUP,IDN,RE,TE,SER,SET,RUP,RDN,ERR)
C SOLVE THE RADIATIVE TRANSFER IN THE MULTI-SUBLAYER SYSTEM
C  BY THE ADDING METHOD.
C--- HISTORY
C 87. 3. 4 FOR INTENSITY CALCULATION.
C 89.10.30 RE-EDIT.
C 96.01.19   EQ22(S2U,ST,N2,NA0,KNDM,KNDM,KNDM,KNDM)
C          ->EQ22(S2U,ST,N2,NA0,KNDM,KNA0,KNDM,KNA0)
C--- INPUT
C NSB       I              NUMBER OF SUBLAYERS.
C NDD    R(NSB1)           NUMBER OF QUADRATURE POINTS AT INTERFACES.
C IUP    I(NSB)            ELEMENT NUMBER OF UPWELLING OPERATORS.
C IDN    I(NSB)            ELEMENT NUMBER OF DOWNGOING OPERATORS.
C NA0       I              NUMBER OF SOLAR ZENITH ANGLES.
C RE    R(KNDM,KNDM,KNLT)  REFLECTION MATRICES OF SUBLAYERS.
C TE    R(KNDM,KNDM,KNLT)  TRANSMISSION MATRICES OF SUBLAYERS.
C SER   R(KNDM,KNA0,KNSB)  UPWELLING SOURCE MATRICES.
C SET   R(KNDM,KNA0,KNSB)  DOWNGOING SOURCE MATRICES.
C--- OUTPUT
C RUP   R(KNDM,KNA0,KNSB1) UPWELLING INTERNAL INTENSITIES.
C RDN   R(KNDM,KNA0,KNSB1) DOWNGOING INTERNAL INTENSITIES.
C ERR      C*64            ERROR INDEX.
C--- PARAMETER
C KNA0      I              NUMBER OF SOLAR ZENITH ANGLES.
C KNDM      I              NUMBER OF QUADRATURE POINTS.
C KNSB      I              NUMBER OF SUBLAYERS.
C KNLT      I              TOTAL NUMBER OF ELEMENTARY OPERATORS
C                           TAKING PORALITY INTO ACCOUNT .GE. KNSB.
C--- AREAS FOR THIS ROUTINE
C
      Include 'VISIRparameters.inc'
c
c      PARAMETER (KNA0  =10)
c      PARAMETER (KNDM  =10)
c      PARAMETER (KNSB  =51)
c      PARAMETER (KNLT  =51)
      PARAMETER (PI=3.141592653)
C      PARAMETER (KNSB1=KNSB+1)
C--- AREAS FOR THE ROUTINE
      CHARACTER ERR*64
      DIMENSION NDD(KNSB1),IUP(KNSB),IDN(KNSB)
     &, RE(KNDM,KNDM,KNLT),  TE(KNDM,KNDM,KNLT)
     &,SER(KNDM,KNA0,KNSB), SET(KNDM,KNA0,KNSB)
     &,RUP(KNDM,KNA0,KNSB1),RDN(KNDM,KNA0,KNSB1)
C--- WORKING AREAS
      DIMENSION R1D(KNDM,KNDM),R1U(KNDM,KNDM),T1D(KNDM,KNDM)
     &,T1U(KNDM,KNDM),S1D(KNDM,KNA0),S1U(KNDM,KNA0)
     &,R2D(KNDM,KNDM),T2D(KNDM,KNDM),T2U(KNDM,KNDM)
     &,S2D(KNDM,KNA0),S2U(KNDM,KNA0),TU(KNDM,KNDM),RD(KNDM,KNDM)
     &,SD(KNDM,KNA0),SU(KNDM,KNA0),RL(KNDM,KNDM,KNSB),SL(KNDM,KNA0,KNSB)
     &,RT(KNDM,KNDM),ST(KNDM,KNA0)
C--- UPWARD ADDING
      NSB1=NSB+1
      ID=IDN(NSB)
      N2=NDD(NSB)
      N3=NDD(NSB1)
      CALL RP33(RL, RE,N2, N2,NSB, ID,KNDM,KNDM,KNSB,KNDM,KNDM,KNLT)
      CALL RP33(SL,SER,N2,NA0,NSB,NSB,KNDM,KNA0,KNSB,KNDM,KNA0,KNSB)
      IF(NSB.GE.2) THEN
        DO 52 L=NSB-1,1,-1
        LB=L
        L1=L+1
        N1=NDD(L)
        IU=IUP(L)
        ID=IDN(L)
        N2=NDD(L1)
        CALL EQ23(R1D, RE,N1, N1,ID,KNDM,KNDM,KNDM,KNDM,KNLT)
        CALL EQ23(R1U, RE,N2, N2,IU,KNDM,KNDM,KNDM,KNDM,KNLT)
        CALL EQ23(T1D, TE,N2, N1,ID,KNDM,KNDM,KNDM,KNDM,KNLT)
        CALL EQ23(T1U, TE,N1, N2,IU,KNDM,KNDM,KNDM,KNDM,KNLT)
        CALL EQ23(S1D,SET,N2,NA0,LB,KNDM,KNA0,KNDM,KNA0,KNSB)
        CALL EQ23(S1U,SER,N1,NA0,LB,KNDM,KNA0,KNDM,KNA0,KNSB)
        CALL EQ23(R2D, RL,N2, N2,L1,KNDM,KNDM,KNDM,KNDM,KNSB)
        CALL EQ23(S2U, SL,N2,NA0,L1,KNDM,KNA0,KNDM,KNA0,KNSB)
        CALL ADD(0,NA0,N1,N2,N3,R1D,R1U,T1D,T1U,S1D,S1U
     &   ,R2D,T2D,T2U,S2D,S2U,TU,RD,SD,SU,ERR)
        IF(ERR.NE.' ') THEN
          ERR='ERROR IN ADD FOR UPWARD ADDING (TRN1)'
          RETURN
        ENDIF
        CALL EQ32( RL, RD,N1, N1,LB,KNDM,KNDM,KNSB,KNDM,KNDM)
        CALL EQ32( SL, SU,N1,NA0,LB,KNDM,KNA0,KNSB,KNDM,KNA0)
   52   CONTINUE
      ENDIF
C FIELD AT THE TOP OF THE SYSTEM
      N1=NDD(1)
      CALL RP33(RUP, SL,N1,NA0,1,1,KNDM,KNA0,KNSB1,KNDM,KNA0,KNSB)
      CALL RP30(RDN,0.0,N1,NA0,1,  KNDM,KNA0,KNSB1)
C--- DOWNWARD ADDING
      IU=IUP(1)
      N1=NDD(1)
      N2=NDD(2)
      CALL EQ23(RT, RE,N2, N2,IU,KNDM,KNDM,KNDM,KNDM,KNLT)
      CALL EQ23(ST,SET,N2,NA0, 1,KNDM,KNA0,KNDM,KNA0,KNSB)
      IF(NSB.GE.2) THEN
        DO 26 L=2,NSB
        LB=L
        N2=NDD(L)
C INTERNAL FIELD
        CALL EQ23(S2U,SL,N2,NA0,LB,KNDM,KNA0,KNDM,KNA0,KNSB)
        CALL EQ23(R2D,RL,N2, N2,LB,KNDM,KNDM,KNDM,KNDM,KNSB)
        CALL AXB(SD,RT,S2U,N2,N2,NA0,KNDM,KNDM,KNDM)
        CALL AAPB(SD,ST,N2,NA0,KNDM,KNDM)
        CALL AXB(RD,RT,R2D,N2,N2,N2,KNDM,KNDM,KNDM)
        CALL MULTI(N2,RD,R1D,ERR)
        IF(ERR.NE.' ') THEN
          ERR='ERROR IN MULTI FOR INTERNAL FIELD (TRN1)'
          RETURN
        ENDIF
        CALL AXB(S1D,R1D,SD,N2,N2,NA0,KNDM,KNDM,KNDM)
        CALL AXB(S1U,R2D,S1D,N2,N2,NA0,KNDM,KNDM,KNDM)
        CALL AAPB(S1U,S2U,N2,NA0,KNDM,KNDM)
        CALL EQ32(RDN,S1D,N2,NA0,LB,KNDM,KNA0,KNSB1,KNDM,KNA0)
        CALL EQ32(RUP,S1U,N2,NA0,LB,KNDM,KNA0,KNSB1,KNDM,KNA0)
C UPSIDE DOWN DIRECTION FOR APPLICATION OF THE ROUTINE ADD.
        IU=IUP(L)
        ID=IDN(L)
        N3=NDD(L+1)
        CALL EQ23(R1D,RE,N3,N3,IU,KNDM,KNDM,KNDM,KNDM,KNLT)
        CALL EQ23(R1U,RE,N2,N2,ID,KNDM,KNDM,KNDM,KNDM,KNLT)
        CALL EQ23(T1D,TE,N2,N3,IU,KNDM,KNDM,KNDM,KNDM,KNLT)
        CALL EQ23(T1U,TE,N3,N2,ID,KNDM,KNDM,KNDM,KNDM,KNLT)
        CALL EQ22(R2D,RT,N2,N2,KNDM,KNDM,KNDM,KNDM)
        CALL EQ23(S1D,SER,N2,NA0,LB,KNDM,KNA0,KNDM,KNA0,KNSB)
        CALL EQ23(S1U,SET,N3,NA0,LB,KNDM,KNA0,KNDM,KNA0,KNSB)
C Bug9601       CALL EQ22(S2U,ST,N2,NA0,KNDM,KNDM,KNDM,KNDM)
        CALL EQ22(S2U,ST,N2,NA0,KNDM,KNA0,KNDM,KNA0)
        CALL ADD(0,NA0,N3,N2,N1,R1D,R1U,T1D,T1U,S1D,S1U
     &  ,R2D,T2D,T2U,S2D,S2U,TU,RT,SD,ST,ERR)
        IF(ERR.NE.' ') THEN
          ERR='ERROR IN ADD FOR DOWNWARD ADDING (TRN1)'
          RETURN
        ENDIF
   26   CONTINUE
      ENDIF
C FIELD AT THE BOTTOM OF THE SYSTEM.
      CALL EQ32(RDN,ST,N3,NA0,NSB1,KNDM,KNA0,KNSB1,KNDM,KNA0)
      CALL RP30(RUP,0.0,N3,NA0,NSB1,KNDM,KNA0,KNSB1)
C--- DOWNWARD ADDING END
      RETURN
      END
